@@ -1,12 +1,12 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.31'; # VERSION
+our $DATE = '2017-01-03'; # DATE
+our $VERSION = '0.32'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::Any '$log';
 use Exporter qw(import);
 our @EXPORT_OK = qw(
                        upload_file
@@ -471,7 +471,6 @@ _
 };
 sub list_dists {
     require List::MoreUtils;
-    require Version::Util;
     use experimental 'smartmatch';
 
     my %args  = @_;
@@ -514,7 +513,7 @@ sub list_dists {
         }
         for my $dist (keys %dist_versions) {
             $dist_versions{$dist} = [
-                sort { -Version::Util::cmp_version($a, $b) }
+                sort { version->parse($a) <=> version->parse($b) }
                     @{ $dist_versions{$dist} }];
             if (@{ $dist_versions{$dist} } > $newest_n) {
                 $dist_versions{$dist} = [splice(
@@ -893,7 +892,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.31 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2016-07-13.
+This document describes version 0.32 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-01-03.
 
 =head1 SYNOPSIS
 
@@ -1450,7 +1449,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
